#!/bin/bash

set -x

PROFILS_DIR="/etc/eole-profile/"
USER_PROFILE="profile"
USER_PROFILE_HOMEDIR="/home/profile"
LOCALES="fr_FR.UTF8"
LANG="fr oss"
FREE_DISPLAY=""
PROFILNAME=""

function test_error(){
	if [ ! "$1"=0 ];then
		zenity --error --text "Une erreur s'est produite dans la fonction $2"
	fi
}

function conform_xdg(){
	su -l "${USER_PROFILE}" -c "xdg-user-dirs-update --force"
}

function lang_mapping(){
    mkdir -p "${USER_PROFILE_HOMEDIR}/.config/autostart/"
    echo "
[Desktop Entry]
Type=Application
Encoding=UTF-8
Version=1.0
Name=Setxkbmap
Name[fr_FR]=setxkbmap
Comment[fr_FR]=setxkbmap
Comment=setxkbmap
Exec=setxkbmap ${LANG}
X-GNOME-Autostart-enabled=true
" > "${USER_PROFILE_HOMEDIR}/.config/autostart/setxkbmap.desktop"
    chown -R "${USER_PROFILE}" "${USER_PROFILE_HOMEDIR}/.config"
}

function purge_home_dir(){
    rm -rf "${USER_PROFILE_HOMEDIR}"
    mkdir "${USER_PROFILE_HOMEDIR}"
    chown -R "${USER_PROFILE}" "${USER_PROFILE_HOMEDIR}"
}

function prepare_home_dir(){
    lang_mapping
    conform_xdg
    su -l "${USER_PROFILE}" -c 'gconftool-2 --type boolean -s /desktop/gnome/peripherals/keyboard/kbd/overrideSettings false'
    su -l "${USER_PROFILE}" -c "mkdir -p "${USER_PROFILE_HOMEDIR}/Bureau""
    su -l "${USER_PROFILE}" -c "cp -f /usr/share/applications/pessulus.desktop "${USER_PROFILE_HOMEDIR}/Bureau""
    chown -R "${USER_PROFILE}" "${USER_PROFILE_HOMEDIR}"
    chmod -R 755 "${USER_PROFILE_HOMEDIR}"
}

function get_valid_display(){
    current_display=`who |awk '{print $5}'|grep : |sed "s/.*:\(.*\)/\1/"|sort -u |tail -n1|sed "s/[():]//g"`
    FREE_DISPLAY=":"`echo ${current_display} + 5  | bc -l`
}

function save_profil(){
    cd ${USER_PROFILE_HOMEDIR}
    rm -rf "Bureau/pessulus.desktop" "${PROFILNAME}.zip"
    su -l "${USER_PROFILE}" -c 'gconftool-2 --type boolean -s /apps/gnome_settings_daemon/screensaver/start_screensaver true'
    rm -f .config/menus/*.menu.undo-*
    for dirs in ".config" ".local" "Bureau";do
    if [ -d $dirs ];then
        zip -gr "${PROFILNAME}" $dirs
    fi
    done
    zip -gr "${PROFILNAME}" ".nautilus/metafiles/file:%2F%2F%2Fhome%2Fprofile%2FBureau.xml"
    su -l "${USER_PROFILE}" -c "gconftool-2 --dump / > .gconf-config.xml"
    zip -gr "${PROFILNAME}" ".gconf-config.xml"
    [ -f .gnome2/monitors.xml ] && zip -gr "${PROFILNAME}" .gnome2/monitors.xml
    mv "${PROFILNAME}.zip" ${PROFILS_DIR}
}

function launch_xnest(){
    sudo /usr/bin/Xephyr "${FREE_DISPLAY}" -ac -br -fullscreen -zaphod -reset -terminate &
    sleep 1
	DISPLAY="${FREE_DISPLAY}" hsetroot -solid "#DAB496" -center /usr/share/eole/backgrounds/eole-splash.png
}

function apply_profil(){
    cd ${USER_PROFILE_HOMEDIR}
    su -l "${USER_PROFILE}" -c "unzip -o \"${PROFILS_DIR}/${PROFILNAME}.zip\""
	su -l "${USER_PROFILE}" -c "gconftool-2 --direct --config-source=xml:readwrite:${USER_PROFILE_HOMEDIR}/.gconf --load .gconf-config.xml"
}

function launch_session(){
    PROFILNAME=${1}
    purge_home_dir
	test_error $? "purge_home_dir"
    prepare_home_dir
	test_error $? "prepare_home_dir"
    if [ -f "${PROFILS_DIR}/${PROFILNAME}.zip" ];then
		apply_profil ${PROFILNAME}
		test_error $? "apply_profil"
    fi
    get_valid_display
	test_error $? "get_valid_display"
    launch_xnest
	test_error $? "launch_xnest"
    su -l "${USER_PROFILE}" -c 'gconftool-2 --type boolean -s /apps/gnome_settings_daemon/screensaver/start_screensaver false'
	test_error $? "Desactivation du screensaver"
    su -l "${USER_PROFILE}" -c "export LANGUAGE=${LOCALES} && export LANG=${LOCALES} && gnome-session --display=${FREE_DISPLAY}"
    save_profil
    test_error $? "save_profil"
    zenity --info --text "Tout s'est bien déroulé le profil est sauvegarde dans ${PROFILNAME}"
}

launch_session $1
